# History


## 0.2.0 (2022-04-23)

  * Basic package functionality is implemented.
  * Tests have been added.
  * Initial documentation is added.

## 0.1.0 (2022-02-08)

* Built initial readme entry to start documenting project goals.
